==> microsite-0.2.0.tgz: package/hydrate.js <==
import React, { forwardRef, createContext, useContext, } from "preact/compat";
import { Buffer } from "buffer";
import { __DocContext } from "./document";
const isServer = typeof window === "undefined";
const btoa = (str) => Buffer.from(str, "utf-8").toString("base64");
const HydrateContext = createContext(false);
export function withHydrate(Component) {
    const name = Component.displayName || Component.name;
    return forwardRef((props, ref) => {
        const { hydrate } = useContext(__DocContext);
        const hydrateParent = useContext(HydrateContext);
        if (hydrateParent)
            throw new Error(`withHydrate() should only be called at the top-level of a Component tree. <${name} /> should not be nested within <${hydrateParent} />`);
        if (isServer)
            hydrate.current.push({ name });
        if (props.children && !["string", "number"].includes(typeof props.children))
            throw new Error(`withHydrate() is unable to serialize complex \`children\`. Please inline these children into <${name} />.`);
        return (React.createElement(HydrateContext.Provider, { value: name },
            React.createElement("div", Object.assign({}, (isServer
                ? {
                    "data-hydrate": name,
                    "data-props": Object.keys(props).length > 0
                        ? btoa(JSON.stringify(props))
                        : null,
                }
                : {})),
                React.createElement(Component, Object.assign({}, Object.assign(Object.assign({}, props), { ref }))))));
    });
}

==> microsite-0.3.0.tgz: package/hydrate.js <==
import React, { forwardRef, createContext, useContext, } from "preact/compat";
import { Buffer } from "buffer";
import { __DocContext } from "./document";
const isServer = typeof window === "undefined";
const btoa = (str) => Buffer.from(str, "utf-8").toString("base64");
const HydrateContext = createContext(false);
export function withHydrate(Component, hydrationProps = {}) {
    const name = Component.displayName || Component.name;
    const { method = 'idle' } = hydrationProps;
    return forwardRef((props, ref) => {
        const { hydrate } = useContext(__DocContext);
        const hydrateParent = useContext(HydrateContext);
        if (hydrateParent)
            throw new Error(`withHydrate() should only be called at the top-level of a Component tree. <${name} /> should not be nested within <${hydrateParent} />`);
        if (isServer)
            hydrate.current.push({ name });
        if (props.children && !["string", "number"].includes(typeof props.children))
            throw new Error(`withHydrate() is unable to serialize complex \`children\`. Please inline these children into <${name} />.`);
        return (React.createElement(HydrateContext.Provider, { value: name },
            React.createElement("div", Object.assign({}, (isServer
                ? {
                    "data-hydrate": name,
                    "data-props": Object.keys(props).length > 0
                        ? btoa(JSON.stringify(props))
                        : null,
                    'data-method': method
                }
                : {})),
                React.createElement(Component, Object.assign({}, Object.assign(Object.assign({}, props), { ref }))))));
    });
}
